      subroutine kir (m,np,uo2,uo3,uco2,uh2o,
     * uo2s,uo3s,uco2s,uh2os,temp,ts,pres,acir)
!      
!  Parameterizations of Fomin and Correa, 2005:  
!   The subroutine is written by Tarasova Aug. 2005
!     infrared solar spectrum, 4 intervals, 11 channels
!               input parameters:
!     m - number of model grid points
!     np - number of levels
!    uco2(m,np),uh2o(m,np) - concentration of CO2,H2O  in molec/(cm2 km) 
!    divided by  1.0e+19 and 1.0e+21
!    uo3(m,np),uo2(m,np)  -  concentration of O3,O2  in molec/(cm2 km) 
!    divided by 1.0e+17 and 1.0e+22
!    uco2s(m,np),uh2os(m,np),uo3s(m,np,),uo2s(m,np), - amount of CO2,H2O,O3,O2 
!    at the solar beam in molec/cm2 divided by 1.0e+19, 1.0e+21, 1.0e+17 and 1.0e+22
!    temp(m,np),ts(m),pres(m,np) - temperature in K, surface temperature in K, pressure in atm
!               output parameter:
!    acir(m,np,20) - volume absorption coefficient (km-1) in 20 channels 5*4
!    
!        
        implicit none  
      integer m, np
      integer i,k,l
      real uco2(m,np),uh2o(m,np),uo2(m,np),uo3(m,np)
      real acir(m,np,20)     
      real uco2s(m,np),uh2os(m,np),uo2s(m,np),uo3s(m,np)      
      real temp(m,np), ts(m), pres(m,np), tmpr, tmpr1
!new
      real ac4o2,u4o2(8),ac4o2l(8)      
      real u7h2o(9),ac7h2ol(9),u8h2o(15),ac8h2ol(15)      
      real u8co2(10),ac8co2l(10),u10h2o(10),ac10h2ol(10)
      real u11h2o(8),ac11h2ol(8),u12h2o(12),ac12h2ol(12)
      real u14h2o(11),ac14h2ol(11),u15h2o(10),ac15h2ol(10)
      
      real ac7h2o,ac8h2o,ac8co2,ac10h2o,ac11h2o,ac12h2o,
     *  ac14h2o,ac15h2o           
!
      data u7h2o/0.001,0.01,0.03,0.1,1.0,
     * 3.0,20.0,100.0,200.0/
      data ac7h2ol/7.61e-2,6.85e-2,6.52e-2,5.98e-2,3.81e-2,
     * 2.72e-2,1.63e-2,1.09e-2,0.978e-2/
      
      data u8h2o/1.0e-6,5.0e-7,1.0e-5,4.0e-5,1.0e-4,5.0e-4,
     * 0.001,0.005,0.01,0.07,0.4,2.0,8.0,20.0,1.0e+2/
      data ac8h2ol/4.0,6.0,7.0,6.0,4.5,
     * 2.0,1.4,1.78,1.75,0.8,0.3,0.05,
     * 0.01,0.004,0.001/ 
         
      data u8co2/4.0e-5,1.0e-4,4.0e-4,0.002,0.01,0.1,
     * 1.0,10.0,100.0,1.0e+3/      
      data ac8co2l/0.8,0.5,0.25,0.1,0.06,
     * 0.02,0.008,0.0045,0.0025,0.0013/
     
      data u10h2o/0.01,0.1,1.0,4.0,10.0,40.0,
     * 70.0,100.0,200.0,1000.0/     
      data ac10h2ol/1.8e-3,2.34e-3,3.19e-3,4.03e-3,4.67e-3,
     * 6.05e-3,6.26e-3,6.37e-3,6.26e-3,5.84e-3/

      data u11h2o/0.01,0.1,1.0,10.0,20.0,
     * 40.0,100.0,1000.0/    
      data ac11h2ol/0.823e-2,1.65e-2,2.35e-2,3.29e-2,3.53e-2,
     * 3.47e-2,2.7e-2,1.76e-2/
     
      data u12h2o/1.0e-4,0.001,0.005,0.0105,0.02,
     * 0.2,0.7,2.0,5.0,20.0,100.0,1.0e+3/     
      data ac12h2ol/1.7,1.22,0.85,0.878,0.756,
     * 0.425,0.255,0.189,0.142,0.085,0.0283,9.45e-4/      

      data u14h2o/1.0e-3,0.01,0.1,1.0,10.0,20.0,
     * 40.0,100.0,150.0,200.0,1000.0/ 
      data ac14h2ol/0.209e-2,0.313e-2,0.584e-2,0.834e-2,1.3e-2,
     * 1.46e-2,1.49e-2,1.25e-2,1.1e-2,1.04e-2,0.834e-2/
      
      data u15h2o/1.0e-5,1.0e-4,0.001,0.01,0.1,1.0,
     * 3.0,10.0,40.0,100.0/     
      data ac15h2ol/7.49,4.16,1.17,1.66,0.749,
     * 0.25,0.125,0.0666,0.0499,0.025/ 
      data u4o2/0.01,0.05,0.1,0.3,1.0,3.0,10.0,100.0/
      data ac4o2l/1.9e-2,1.8e-2,1.5e-2,1.0e-2,0.7e-2,0.48e-2,
     * 0.25e-2,0.25e-2/            
!      
      do i=1,m
      do k=1,np
!
      ac4o2=ac4o2l(1)
      if (uo2s(i,k).gt.u4o2(8)) ac4o2=ac4o2l(8)
      do l=1,7      
      if (uo2s(i,k).gt.u4o2(l).and.uo2s(i,k).le.u4o2(l+1)) then 
      ac4o2=ac4o2l(l)+(ac4o2l(l)-ac4o2l(l+1))*(uo2s(i,k)-
     * u4o2(l))/(u4o2(l)-u4o2(l+1)) 
      endif      
      enddo
!tar
      acir(i,k,1)=ac4o2*uo2(i,k)
      acir(i,k,2)=0.      
      acir(i,k,3)=0.
      acir(i,k,4)=0.           
!tar  
        tmpr=3.2**((300.0-temp(i,k))/43.0)
	tmpr1=3.2**((300.0-temp(i,k))/25.0)
	
      acir(i,k,5)=1.35e-4*(1.0-0.0007*(300.0-temp(i,k)))*
     * (pres(i,k)**0.77)*uh2o(i,k)+1.19e-5*(pres(i,k)**0.59)*uo2(i,k)+
     * 1.7e-5*uo3(i,k) 
      
      acir(i,k,6)=2.1e-3*(pres(i,k)**0.55)*uh2o(i,k)+
     * 1.4e-5*uo3(i,k)	
!
      ac7h2o=ac7h2ol(1)                 
      if (uh2os(i,k).gt.u7h2o(9)) ac7h2o=ac7h2ol(9)
             
      do l=1,8      
      if (uh2os(i,k).gt.u7h2o(l).and.uh2os(i,k).le.u7h2o(l+1)) then 
      ac7h2o=ac7h2ol(l)+(ac7h2ol(l)-ac7h2ol(l+1))*(uh2os(i,k)-
     * u7h2o(l))/(u7h2o(l)-u7h2o(l+1)) 
      endif
      enddo
      
!      write (*,*) 'ac7h2o='
!      write (*,30) ac7h2o
      
      acir(i,k,7)=ac7h2o*uh2o(i,k)
      acir(i,k,8)=0.      
!
      ac8h2o=ac8h2ol(1)
      if (uh2os(i,k).gt.u8h2o(15)) ac8h2o=ac8h2ol(7) 
      do l=1,14      
      if (uh2os(i,k).gt.u8h2o(l).and.uh2os(i,k).le.u8h2o(l+1)) then 
      ac8h2o=ac8h2ol(l)+(ac8h2ol(l)-ac8h2ol(l+1))*(uh2os(i,k)-
     * u8h2o(l))/(u8h2o(l)-u8h2o(l+1)) 
      endif      
      enddo
!
!      write (*,*) 'ac8h2o='
!      write (*,30) ac8h2o
              
!      
      ac8co2=ac8co2l(1)
      if (uco2s(i,k).gt.u8co2(10)) ac8co2=ac8co2l(10) 
      do l=1,9      
      if (uco2s(i,k).gt.u8co2(l).and.uco2s(i,k).le.u8co2(l+1)) then 
      ac8co2=ac8co2l(l)+(ac8co2l(l)-ac8co2l(l+1))*(uco2s(i,k)-
     * u8co2(l))/(u8co2(l)-u8co2(l+1)) 
      endif      
      enddo
!
!      write (*,*) 'ac8co2='
!      write (*,30) ac8co2      
                  
       acir(i,k,9)=ac8h2o*uh2o(i,k)+ac8co2*uco2(i,k) 
       acir(i,k,10)=0. 
       acir(i,k,11)=0.
       acir(i,k,12)=0.                          
!
      acir(i,k,13)=3.77e-4*(1.0-0.00372*(300.0-temp(i,k)))*
     * (pres(i,k)**0.65)*uh2o(i,k)+6.5e-7*tmpr*
     * (uh2o(i,k)**2.0)+1.55e-5*(pres(i,k)**0.54)*uco2(i,k)
!
!
      ac10h2o=ac10h2ol(1)
      if (uh2os(i,k).gt.u10h2o(10)) ac10h2o=ac10h2ol(10)       
      do l=1,9      
      if (uh2os(i,k).gt.u10h2o(l).and.uh2os(i,k).le.u10h2o(l+1)) then 
      ac10h2o=ac10h2ol(l)+(ac10h2ol(l)-ac10h2ol(l+1))*(uh2os(i,k)-
     * u10h2o(l))/(u10h2o(l)-u10h2o(l+1)) 
      endif      
      enddo
      
!      write (*,*) 'ac10h2o='
!      write (*,30) ac10h2o      
      
!      
      acir(i,k,14)=ac10h2o*((300.0/ts(i))**1.3)*uh2o(i,k)+6.5e-6*tmpr*
     * (uh2o(i,k)**2.0)+2.09e-5*(pres(i,k)**0.626)*uco2(i,k)
      
       ac11h2o=ac11h2ol(1)
      if (uh2os(i,k).gt.u11h2o(8)) ac11h2o=ac11h2ol(8)       
      do l=1,7      
      if (uh2os(i,k).gt.u11h2o(l).and.uh2os(i,k).le.u11h2o(l+1)) then 
      ac11h2o=ac11h2ol(l)+(ac11h2ol(l)-ac11h2ol(l+1))*(uh2os(i,k)-
     * u11h2o(l))/(u11h2o(l)-u11h2o(l+1)) 
      endif      
      enddo
      
!      write (*,*) 'ac11h2o='
!      write (*,30) ac11h2o      
      
!      
      acir(i,k,15)= ac11h2o*((300.0/ts(i))**2.1)*uh2o(i,k)+2.5e-5*tmpr*
     * (uh2o(i,k)**2.0)+2.60e-5*(pres(i,k)**0.606)*uco2(i,k)    
 
 
        ac12h2o=ac12h2ol(1)
      if (uh2os(i,k).gt.u12h2o(12)) ac12h2o=ac12h2ol(12)       
      do l=1,11      
      if (uh2os(i,k).gt.u12h2o(l).and.uh2os(i,k).le.u12h2o(l+1)) then 
      ac12h2o=ac12h2ol(l)+(ac12h2ol(l)-ac12h2ol(l+1))*(uh2os(i,k)-
     * u12h2o(l))/(u12h2o(l)-u12h2o(l+1)) 
      endif      
      enddo
      
!      write (*,*) 'ac12h2o='
!      write (*,30) ac12h2o      
      
!      
      acir(i,k,16)= ac12h2o*((300.0/ts(i))**1.2)*uh2o(i,k)+8.0e-5*tmpr*
     * (uh2o(i,k)**2.0)+6.85e-6*(pres(i,k)**0.518)*uco2(i,k)    
! 
      acir(i,k,17)= 1.3e-3*(1.0-0.00235*(300.0-temp(i,k)))*
     * (pres(i,k)**0.65)*uh2o(i,k)+6.0e-6*tmpr*(uh2o(i,k)**2.0)+
     * 1.99e-5*(pres(i,k)**0.782)*uco2(i,k)     
!

        ac14h2o=ac14h2ol(1)
      if (uh2os(i,k).gt.u14h2o(11)) ac14h2o=ac14h2ol(11)       
      do l=1,10      
      if (uh2os(i,k).gt.u14h2o(l).and.uh2os(i,k).le.u14h2o(l+1)) then 
      ac14h2o=ac14h2ol(l)+(ac14h2ol(l)-ac14h2ol(l+1))*(uh2os(i,k)-
     * u14h2o(l))/(u14h2o(l)-u14h2o(l+1)) 
      endif      
      enddo
      
!      write (*,*) 'ac14h2o='
!      write (*,30) ac14h2o      
      
!      
      acir(i,k,18)= ac14h2o*uh2o(i,k)+2.6e-5*tmpr*
     * (uh2o(i,k)**2.0)+9.49e-6*(pres(i,k)**0.609)*uco2(i,k)                
!
        ac15h2o=ac15h2ol(1)
      if (uh2os(i,k).gt.u15h2o(10)) ac15h2o=ac15h2ol(10)       
      do l=1,9      
      if (uh2os(i,k).gt.u15h2o(l).and.uh2os(i,k).le.u15h2o(l+1)) then 
      ac15h2o=ac15h2ol(l)+(ac15h2ol(l)-ac15h2ol(l+1))*(uh2os(i,k)-
     * u15h2o(l))/(u15h2o(l)-u15h2o(l+1)) 
      endif      
      enddo
      
!      write (*,*) 'ac15h2o='
!      write (*,30) ac15h2o      
      
!      
      acir(i,k,19)= ac15h2o*uh2o(i,k)+2.0e-4*tmpr1*
     * (uh2o(i,k)**2.0)+3.64e-5*(pres(i,k)**0.799)*uco2(i,k)                
!        
       acir(i,k,20)=0.
!           
      enddo
      enddo
      
  30   format (1E12.4)
   
      return
      end
      
      





